@@ -1,11 +1,13 @@
 "error.bars" <-
-function (x,ylab ="Dependent Variable",xlab="Independent Variable", main="95% confidence limits",ylim= NULL, ci=1.96, labels=NULL,pos=NULL,arrow.len=.05,add=FALSE,...)  # x   data frame with 
+function (x,ylab ="Dependent Variable",xlab="Independent Variable", main=NULL,ylim= NULL, alpha=.05, labels=NULL,pos=NULL,arrow.len=.05,add=FALSE,...)  # x   data frame with 
     {
     x.stats <- describe(x)
     z <- dim(x)[2]
     min.x <- min(x.stats$mean)
     max.x <- max(x.stats$mean)
     max.se <- max(x.stats$se)
+    ci <- qt(1-alpha/2,x.stats$n)
+    if(is.null(main)) main = paste(1-alpha,"% confidence limits",sep="") 
     if(is.null(ylim)) {ylim=c(min.x - 2*max.se,max.x+2*max.se)}
     if(!add) {plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,axes=FALSE,main=main,...)
      axis(1,1:z,colnames(x))
